@@ -26,7 +26,7 @@ use Term::ReadKey;
 use JSON::XS;
 use List::MoreUtils 'firstidx';
 
-our $VERSION = '0.4.1'; # VERSION
+our $VERSION = '0.5.0'; # VERSION
 
 has app  => ( is => 'ro' );
 has repo => ( is => 'ro' );
@@ -193,7 +193,7 @@ sub _download_binary_file {
   mkpath( dirname( $option{dest} ) ) if ( !-d dirname $option{dest} );
 
   if ( -f $option{dest} && !$option{force} ) {
-    $self->app->logger->debug("Skipping $option{url}. File aready exists.");
+    $self->app->logger->debug("Skipping $option{url}. File already exists.");
     return;
   }
 
